@@ -73,15 +73,19 @@ def azureml_timer(logger, run):
             t1 = time.time()
             result = func(*args, **kwargs)
             t2 = time.time() - t1
-            custom_dimensions = {
-                                "parent_run_id": run.parent.id,
-                                "step_id": run.id,
-                                "step_name": run.name,
-                                "experiment_name": run.experiment.name,
-                                "run_url": run.parent.get_portal_url(),
-                                "duration_in_sec": t2,
-                                "method_name":func.__name__
-                                }
+            if run.parent:
+                custom_dimensions = {
+                                    "parent_run_id": run.parent.id,
+                                    "step_id": run.id,
+                                    "step_name": run.name,
+                                    "experiment_name": run.experiment.name,
+                                    "run_url": run.parent.get_portal_url(),
+                                    "duration_in_sec": t2,
+                                    "method_name":func.__name__
+                                    }
+            else:
+                custom_dimensions = {"duration_in_sec": t2, "method_name":func.__name__}
+
             logger.warning('{} ran in: {} sec'.format(func.__name__, t2), custom_dimensions)
             return result
         
@@ -1270,6 +1274,10 @@ class AzureMLRunMoq:
     def log(self, title, value):
         print("title :", title)
         print("value :", value)
+    
+    def tag(self, title, value):
+        print("title :", title)
+        print("value :", value)
 
     def log_image(self, title, plot):
         print("tile:", title)
